#! /bin/sh
#
# MySQL database dump with MySQL root user - call as Linux root user!
# Part of mysql-addons package. Original from Alex Hornyak (THX!).
# 
# Usage: mysql_dumpdb.sh [-c|--compress] database [backup_path|- [dump_user]]

EXIT_ERR="1"

# Need to be root.
if [ ! $UID -eq 0 ]; then echo "Run as root, please." >&2; exit $EXIT_ERR; fi

# Getting parameters.
# Optional compress switch (-c or --compress).
option=`echo $1 | sed -n "s/^-\+//p"`; if [ ! -z "$option" ]; then shift; fi
if [ "$option" = "c" -o "$option" = "compress" ]; then 
    compress="/bin/gzip"
else 
    compress="cat"
fi
# Mandatory database name.
database=${1?"Usage: $0 [-c|--compress] database [backup_path|- [dump_user]]"};shift
# Optional backup file pathname, defaults to ./hostname.timestamp.database.sql
filename=${1:-`pwd`/`hostname`.`date +%Y%m%d%H%M%S`.$database.sql}; shift
if [ "$filename" = "-" ]; then
    # If '-' given as filename outpust to STDOUT.
    filename=""
else
    # If compressed, adjusting filename to sql.gz.
    case "${compress##*/}" in
        "gzip")
        filename="${filename%.gz}.gz"
        ;;
    esac
fi
# Optional Linux backups owner defaults to 'backup'.
dumpuser=${1:-"backup"}; shift
# Wired access rights.
dumpfilerights="640"
# MySQL command line call as MySQL root user.
mysql_dsm="/usr/bin/mysql --defaults-file=/etc/mysql/root.cnf"
# MySQL dump command line call as MySQL root user.
mysqldump_dsm="/usr/bin/mysqldump --defaults-file=/etc/mysql/root.cnf"
# MySQL 5.x dump parameters (stored procedures also).
dumpparameters="--all --databases --complete-insert --add-drop-table --extended-insert --routines"

# Checking database given.
if [ -z "`$mysql_dsm --batch --execute='show databases;' | \
          sed s/^Database$// | \
          sed -n s/^$database$/X/p`" ]; then
    echo "MySQL database \"$database\" isn't found." >&2
    exit $EXIT_ERR
fi
# Doing some cleanup.
if [ -f "$filename" ]; then rm "$filename"; fi
if [ ! -z "$filename" ]; then
    # Dump into a file.
    $mysqldump_dsm $dumpparameters $database | $compress >"$filename"
    chown $dumpuser "$filename"; chmod $dumpfilerights "$filename"
else
    # Dump to STDOUT.
    $mysqldump_dsm $dumpparameters $database | $compress
fi
